#
# spec file for package python-platformdirs
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-platformdirs%{psuffix}
Version:        4.3.7
Release:        1.1
Summary:        Module for determining appropriate platform-specific dirs
License:        MIT
URL:            https://github.com/platformdirs/platformdirs
Source:         https://files.pythonhosted.org/packages/source/p/platformdirs/platformdirs-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module hatch-vcs}
BuildRequires:  %{python_module hatchling >= 0.22.0}
BuildRequires:  %{python_module pip}
%if %{with test}
BuildRequires:  %{python_module appdirs == 1.4.4}
BuildRequires:  %{python_module platformdirs = %{version}}
BuildRequires:  %{python_module pytest >= 7.4}
BuildRequires:  %{python_module pytest-cov >= 4.1}
BuildRequires:  %{python_module pytest-mock >= 3.11.1}
%endif
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
A small Python module for determining appropriate platform-specific dirs, e.g. a "user data dir".

%prep
%autosetup -p1 -n platformdirs-%{version}

%build
%if !%{with test}
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pytest
%endif

%if !%{with test}
%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/platformdirs
%{python_sitelib}/platformdirs-%{version}.dist-info
%endif

%changelog
* Mon Apr 28 2025 Dirk Müller <dmueller@suse.com>
- update to 4.3.7:
  * Chunk dependabot updates into a single PR
  * Drop support for EOL Python 3.8
* Wed Feb  5 2025 Daniel Garcia <daniel.garcia@suse.com>
- Use multibuild for test package
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 4.3.6:
  * Fix readme download target
- update to 4.3.5:
  * Split build and publish for release
- update to 4.3.4:
  * Use upstream setup-uv with uv python
- update to 4.3.3:
  * Update check.yml
  * don't include outdated changelog in docs
- update to 4.3.2:
  * Use uv as installer
  * Fix multi-path returned from `_path` methods on MacOS
- update to 4.3.0:
  * Speed up Hatch installation
  * Test with Python 3.13
  * Test with latest PyPy
  * Use `include-hidden-files: true` to upload coverage artifacts
  * Ensure PlatformDirs is valid superclass type for mypy AND not
    an abstract class for other checkers
* Tue Jun  4 2024 Dirk Müller <dmueller@suse.com>
- update to 4.2.2:
  * Fix android detection when python4android is present
* Sat Apr 27 2024 Dirk Müller <dmueller@suse.com>
- update to 4.2.1:
  * Switch to ruff for formatting and use codespell and
    docformatter
  * Use hatch over tox
  * Allow working without ctypes
* Thu Feb  1 2024 Dirk Müller <dmueller@suse.com>
- update to 4.2.0:
  * Fix 2 typos about XDG_DATA_DIR
  * Add convenience methods to `PlatformDirsAPI` that allow
    iterating over both user and site dirs/paths.
* Mon Jan  1 2024 Dirk Müller <dmueller@suse.com>
- update to 4.1.0:
  * docs: fix Linux user_log_dir example in README
  * Drop support for EOL Python 3.7
- update to 4.0.0:
  * site_cache_dir: Use `/var/cache` again instead of `/var/tmp`
    on UNIX
* Thu Nov  9 2023 ecsos <ecsos@opensuse.org>
- Update to 3.11.0
  - README: Fix CI badge in #222
  - Fix documentation build in #225
  - Add support for Homebrew-installed software in #232
- Changes from 3.10.0
  - Fix docs build failure in #210
  - platformdirs: introduce site_runtime_dir in #212
- Changes from 3.9.1
  - unix: Optionally create the opinionated log/ in user_log_dir()
    in #208
- Changes from 3.9.0
  - Added desktop folder in #200
- Changes from 3.8.1
  - BSD: provide a fallback for user_runtime_dir in #201
- Changes from 3.8.0
  - Add missing user media directory docs in #195
- Changes from 3.7.0
  - Have user_runtime_dir return /var/run/user/uid for *BSD in #194
- Changes from 3.6.0
  - platformdirs: introduce user_downloads_dir() in #192
- Changes from 3.5.3
  - https://github.com/platformdirs/platformdirs/compare/3.5.2...3.5.3
- Changes from 3.5.2
  - git ls-files -z -- .github/workflows/check.yml | xargs -0
    sed -i 's|3.12.0-alpha.7|3.12.0-beta.1|g' in #187
  - Use ruff in #189
* Fri Jun  2 2023 Dirk Müller <dmueller@suse.com>
- update to 3.5.1:
  * Add 3.12 support
  * Add tox.ini to sdist
  * removing Windows versions
  * Better handling for UNIX support
  * platformdirs: introduce `user_music_dir()`
  * platformdirs: introduce `user_videos_dir()`
  * Adding platformdirs.PlatformDirs to docs
  * Fix linter failures
  * Exclude bots from generated release notes
  * platformdirs: introduce `user_pictures_dir()`
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sun Apr  2 2023 Andreas Prittwitz <m4ng4n@gmx.de>
- update to 3.2.0
  * Remove reference to missing CHANGES.rst in %%doc section
  * Rename %%license reference to LICENSE
  * Add pyproject-fmt by @gaborbernat in #150
  * Bump deps and tools by @gaborbernat in #149
  * Bump pypa/gh-action-pypi-publish from 1.6.4 to 1.7.1 by
    @dependabot in #151
  * Bump pypa/gh-action-pypi-publish from 1.7.1 to 1.8.1 by
    @dependabot in #153
  * Bump deps and tools by @gaborbernat in #154
  * Bump pypa/gh-action-pypi-publish from 1.8.1 to 1.8.3 by
    @dependabot in #156
  * Add option to create directories by @smsearcy in #155
- changes in 3.1.1
  * site_cache_dir: use /var/tmp instead of /var/cache on unix by
    @efiop in #148
- changes in 3.1.0
  * rst: fix backtics by @efiop in #146
  * platformdirs: introduce site_cache_dir by @efiop in #145
- changes in 3.0.1
  * pyproject.toml: add appdirs keyword by @efiop in #144
- changes in 3.0.0
  * Fix CI by @gaborbernat in #125
  * Use the correct project name in documentation by @pradyunsg in
    [#131]
  * Fix CI by @gaborbernat in #138
  * Fix macos user_site_dir by @ThomasWaldmann in #137
- changes in 2.6.2
  * Add typing-extensions as dependency when python_version < 3.8
    by @amacf in #123
- changes in 2.6.1
  * Bump pypa/gh-action-pypi-publish from 1.6.1 to 1.6.4 by
    @dependabot in #116
  * Fix the CI, bump tools by @gaborbernat in #119
  * Coverage reporting fixes by @nedbat in #121
  * Fix #114 by @Freed-Wu in #115
- changes in 2.6.0
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #107
  * Bump pypa/gh-action-pypi-publish from 1.5.1 to 1.5.2 by
    @dependabot in #111
  * Bump pypa/gh-action-pypi-publish from 1.5.2 to 1.6.1 by
    @dependabot in #113
  * Change user_log_dir to point to user_state_dir on Linux per the
    XDG spec by @lordwelch in #108
- changes in 2.5.4
  * Update check.yml
- changes in 2.5.3
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #80
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #82
  * Bump pre-commit/action from 2.0.3 to 3.0.0 by @dependabot in
    [#87]
  * Bump actions/upload-artifact from 2 to 3 by @dependabot in #86
  * Bump actions/download-artifact from 2 to 3 by @dependabot in
    [#85]
  * Bump actions/setup-python from 2 to 4 by @dependabot in #84
  * Bump actions/checkout from 2 to 3 by @dependabot in #83
  * Docs: platformdirs is a package by @chanicpanic in #88
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #89
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #91
  * Check 3.11 support by @gaborbernat in #92
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #93
  * Bump tools by @gaborbernat in #94
  * Bump dependencies by @gaborbernat in #95
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #96
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #99
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #100
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #101
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #102
  * Declare support for Python 3.11 by @hugovk in #103
* Mon Aug 22 2022 Ben Greiner <code@bnavigator.de>
- Update to 2.5.2:
  * Move packaging to hatchling from setuptools
  * Treat android shells as unix
- Disable building the docs.
  * It's the only package in Ring1 pulling in
    python-sphinx-autodoc-typehints and thus python-nptyping and
    python-beartype. Avoid it. The online docs should be enough
    nowadays.
  * Drop no-furo.patch
* Sat Mar 26 2022 Dirk Müller <dmueller@suse.com>
- update to 2.5.1:
  - Add native support for nuitka
  - Add support for Termux subsystems
* Mon Jan 10 2022 Dirk Müller <dmueller@suse.com>
- update to 2.4.1:
  * python 3.6 removal
* Sun Oct  3 2021 Ben Greiner <code@bnavigator.de>
- Update to version 2.4.0
  * Add user_documents_dir
  * Add user_runtime_dir and its path-returning equivalent (#37)
- Fix egg-info version: build requires setuptools_scm >= 5
* Tue Aug  3 2021 Matej Cepl <mcepl@suse.com>
- Initial package for platformdirs 2.2.0.
- Add no-furo.patch to avoid using furo Sphinx theme
  (https://github.com/pradyunsg/furo/discussions/148#discussioncomment-1125486)
